# AzureStack

> see https://aka.ms/autorest

This is the AutoRest configuration file for Azure Stack.

The Azure Stack RP comprises of small services where each service has its own tag.
Hence, each sub-service has its own swagger spec.

All of them are tied together using this configuration and are packaged together into one Azure Stack client library.
This makes it easier for customers to download one (NuGet/npm/pip/maven/gem) Azure Stack client library package rather than installing individual packages for each sub service.

---

## Getting Started

To build the SDK for Azure Stack, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

## Configuration

### Basic Information

These are the global settings for the Azure Stack API.

``` yaml
title: AzureStackManagementClient
description: Azure Stack
openapi-type: arm
tag: package-preview-2020-06
```


### Tag: package-2016-01

These settings apply only when `--tag=package-2016-01` is specified on the command line.

```yaml $(tag) == 'package-2016-01'
input-file:
  - Microsoft.AzureStack/stable/2016-01-01/AzureStack.json
  - Microsoft.AzureStack/stable/2016-01-01/Product.json
  - Microsoft.AzureStack/stable/2016-01-01/Registration.json
```
### Tag: package-2017-06-01

These settings apply only when `--tag=package-2017-06-01` is specified on the command line.

``` yaml $(tag) == 'package-2017-06-01'
input-file:
- Microsoft.AzureStack/stable/2017-06-01/AzureStack.json
- Microsoft.AzureStack/stable/2017-06-01/Product.json
- Microsoft.AzureStack/stable/2017-06-01/Registration.json
- Microsoft.AzureStack/stable/2017-06-01/CustomerSubscription.json
```
### Tag: package-preview-2020-06

These settings apply only when `--tag=package-preview-2020-06` is specified on the command line.

```yaml $(tag) == 'package-preview-2020-06'
input-file:
  - Microsoft.AzureStack/preview/2020-06-01-preview/AzureStack.json
  - Microsoft.AzureStack/preview/2020-06-01-preview/CustomerSubscription.json
  - Microsoft.AzureStack/preview/2020-06-01-preview/Product.json
  - Microsoft.AzureStack/preview/2020-06-01-preview/Registration.json
  - Microsoft.AzureStack/preview/2020-06-01-preview/LinkedSubscription.json
```

---

### Validations

Run validations when `--validate` is specified on command line

``` yaml $(validate)
azure-validator: true
model-validator: true
semantic-validator: true
message-format: json
```

---

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-python-track2
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-resource-manager-schemas
```

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  # last generated with AutoRest.1.0.0-Nightly20170126
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.AzureStack
  payload-flattening-threshold: 1
  output-folder: $(csharp-sdks-folder)/azurestack/Microsoft.Azure.Management.AzureStack/src/Generated
  clear-output-folder: true
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.azurestack
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-azurestack
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2017-06-01
```

### Tag: package-2017-06-01 and java

These settings apply only when `--tag=package-2017-06-01 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2017-06-01' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.azurestack.v2017_06_01
  output-folder: $(azure-libraries-for-java-folder)/sdk/azurestack/mgmt-v2017_06_01
regenerate-manager: true
generate-interface: true
```

## Python

See configuration in [readme.python.md](./readme.python.md)


