# Cognitive Services Language SDK

The Cognitive Service Language SDK has support for the Text Analytics Cognitive Service.
While this repository contains the [Autorest](https://aka.ms/autorest) generated SDK, the easiest way to consume the SDK is by installing the NuGet package for it.

Note that the Cognitive Services Language SDK is simply a wrapper on top of the Text Analytics Cognitive service. As such, it will generate calls to the Azure service.


## Prerequisites
You must have a [Cognitive Services API account](https://docs.microsoft.com/azure/cognitive-services/cognitive-services-apis-create-account) with **Text Analytics API**.

You must also have the [endpoint and access key](../How-tos/text-analytics-how-to-access-key.md) that was generated for you during sign up.

## Installing the NuGet SDK Package
1. Create a new Console solution in Visual Studio.
1. Right click on the solution and click **Manage NuGet Packages for Solution**
1. Select the **Browse** tab, and Search for **Microsoft.AI.TextAnalytics**
1. Select the NuGet package and install it.

## Calling the Text Analytics API using the SDK
See Text Analytics [Quickstart guide](https://docs.microsoft.com/en-us/azure/cognitive-services/text-analytics/quickstarts/text-analytics-sdk?tabs=version-3&pivots=programming-language-csharp) for detailed instructions on how to use the SDK in your application.

## Releases

> see https://aka.ms/autorest

The current release is `release_2_1`.
A preview release `release_2_1_preview` is also available.

``` yaml
tag: release_2_1
add-credentials: true

directive:
  - suppress: LongRunningResponseStatusCode
    reason: The validation tools do not properly recognize 202 as a supported response code.
```

### Release 2.0

These settings apply only when `--tag=release_2_0` is specified on the command line.

``` yaml $(tag) == 'release_2_0'
input-file: stable/v2.0/TextAnalytics.json
```

### Release 2.1

These settings apply only when `--tag=release_2_1` is specified on the command line.

``` yaml $(tag) == 'release_2_1'
input-file: stable/v2.1/TextAnalytics.json
```

### Release 2.1-Preview

These settings apply only when `--tag=release_2_1_preview` is specified on the command line.

``` yaml $(tag) == 'release_2_1_preview'
input-file: preview/v2.1/TextAnalytics.json
```

### Release 3.0-Preview.1

These settings apply only when `--tag=release_3_0_preview.1` is specified on the command line.

``` yaml $(tag) == 'release_3_0_preview.1'
input-file: preview/v3.0-preview.1/TextAnalytics.json
```

### Release 3.0

These settings apply only when `--tag=release_3_0` is specified on the command line.

``` yaml $(tag) == 'release_3_0'
input-file: stable/v3.0/TextAnalytics.json
```

### Release 3.1-Preview.1

These settings apply only when `--tag=release_3_1_preview.1` is specified on the command line.

``` yaml $(tag) == 'release_3_1_preview.1'
input-file: preview/v3.1-preview.1/TextAnalytics.json
```

### Release 3.1-Preview.2

These settings apply only when `--tag=release_3_1_preview.2` is specified on the command line.

``` yaml $(tag) == 'release_3_1_preview.2'
input-file: preview/v3.1-preview.2/TextAnalytics.json
```

### Release 3.1-Preview.3

These settings apply only when `--tag=release_3_1_preview.3` is specified on the command line.

``` yaml $(tag) == 'release_3_1_preview.3'
input-file: preview/v3.1-preview.3/TextAnalytics.json
```

### Release 3.1-Preview.4

These settings apply only when `--tag=release_3_1_preview.4` is specified on the command line.

```yaml $(tag) == 'release_3_1_preview.4'
input-file: preview/v3.1-preview.4/TextAnalytics.json
```

### Release 3.1-Preview.5

These settings apply only when `--tag=release_3_1_preview.5` is specified on the command line.

```yaml $(tag) == 'release_3_1_preview.5'
input-file: preview/v3.1-preview.5/TextAnalytics.json
```

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_cognitiveservices_textanalytics']
```

## CSharp Settings

These settings apply only when `--csharp` is specified on the command line.

``` yaml $(csharp)
csharp:
  sync-methods: None
  license-header: MICROSOFT_MIT_NO_VERSION
  azure-arm: false
  namespace: Microsoft.Azure.CognitiveServices.Language.TextAnalytics
  output-folder: $(csharp-sdks-folder)/CognitiveServices/Language.TextAnalytics/src/Generated
  clear-output-folder: true
```

## Python

See configuration in [readme.python.md](./readme.python.md)

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  namespace: com.microsoft.azure.cognitiveservices.language.textanalytics
  license-header: MICROSOFT_MIT_NO_CODEGEN
  payload-flattening-threshold: 1
  output-folder: $(azure-libraries-for-java-folder)/cognitiveservices/data-plane/language/textanalytics
  with-optional-parameters: true
  with-single-async-method: true
```
