# DNS

> see https://aka.ms/autorest

This is the AutoRest configuration file for DNS.

---

## Getting Started

To build the SDK for DNS, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

## Configuration

### Basic Information

These are the global settings for the DNS API.

``` yaml
openapi-type: arm
tag: package-2018-05
```


### Tag: package-2018-05

These settings apply only when `--tag=package-2018-05` is specified on the command line.

```yaml $(tag) == 'package-2018-05'
input-file:
  - Microsoft.Network/stable/2018-05-01/dns.json
directive:
  - where:
      - $.paths
    suppress:
      - OperationsAPIImplementation
  - where:
      - $.definitions.RecordSetProperties.properties.TTL
      - $.definitions.RecordSetProperties.properties.ARecords
      - $.definitions.RecordSetProperties.properties.AAAARecords
      - $.definitions.RecordSetProperties.properties.MXRecords
      - $.definitions.RecordSetProperties.properties.NSRecords
      - $.definitions.RecordSetProperties.properties.PTRRecords
      - $.definitions.RecordSetProperties.properties.SRVRecords
      - $.definitions.RecordSetProperties.properties.TXTRecords
      - $.definitions.RecordSetProperties.properties.CNAMERecord
      - $.definitions.RecordSetProperties.properties.SOARecord
      - $.definitions.RecordSetUpdateParameters.properties.RecordSet
    suppress:
      - DefinitionsPropertiesNamesCamelCase  
```
### Tag: package-2018-03-preview

These settings apply only when `--tag=package-2018-03-preview` is specified on the command line.

``` yaml $(tag) == 'package-2018-03-preview'
input-file:
- Microsoft.Network/preview/2018-03-01-preview/dns.json
directive:
  - where:
      - $.paths
    suppress:
      - OperationsAPIImplementation
  - where:
      - $.definitions.RecordSetProperties.properties.TTL
      - $.definitions.RecordSetProperties.properties.ARecords
      - $.definitions.RecordSetProperties.properties.AAAARecords
      - $.definitions.RecordSetProperties.properties.MXRecords
      - $.definitions.RecordSetProperties.properties.NSRecords
      - $.definitions.RecordSetProperties.properties.PTRRecords
      - $.definitions.RecordSetProperties.properties.SRVRecords
      - $.definitions.RecordSetProperties.properties.TXTRecords
      - $.definitions.RecordSetProperties.properties.CNAMERecord
      - $.definitions.RecordSetProperties.properties.SOARecord
      - $.definitions.RecordSetUpdateParameters.properties.RecordSet
    suppress:
      - DefinitionsPropertiesNamesCamelCase
```

### Tag: package-2017-10

These settings apply only when `--tag=package-2017-10` is specified on the command line.

``` yaml $(tag) == 'package-2017-10'
input-file:
- Microsoft.Network/stable/2017-10-01/dns.json
directive:
  - where:
      - $.paths
    suppress:
      - OperationsAPIImplementation
  - where:
      - $.definitions.RecordSetProperties.properties.TTL
      - $.definitions.RecordSetProperties.properties.ARecords
      - $.definitions.RecordSetProperties.properties.AAAARecords
      - $.definitions.RecordSetProperties.properties.MXRecords
      - $.definitions.RecordSetProperties.properties.NSRecords
      - $.definitions.RecordSetProperties.properties.PTRRecords
      - $.definitions.RecordSetProperties.properties.SRVRecords
      - $.definitions.RecordSetProperties.properties.TXTRecords
      - $.definitions.RecordSetProperties.properties.CNAMERecord
      - $.definitions.RecordSetProperties.properties.SOARecord
      - $.definitions.RecordSetUpdateParameters.properties.RecordSet
    suppress:
      - DefinitionsPropertiesNamesCamelCase
```

### Tag: package-2017-09

These settings apply only when `--tag=package-2017-09` is specified on the command line.

``` yaml $(tag) == 'package-2017-09'
input-file:
- Microsoft.Network/stable/2017-09-01/dns.json
```

### Tag: package-2016-04

These settings apply only when `--tag=package-2016-04` is specified on the command line.

``` yaml $(tag) == 'package-2016-04'
input-file:
- Microsoft.Network/stable/2016-04-01/dns.json
```

### Tag: package-2015-05-preview

These settings apply only when `--tag=package-2015-05-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-05-preview'
input-file:
- Microsoft.Network/preview/2015-05-04-preview/dns.json
```

### Tag: profile-hybrid-2020-09-01

These settings apply only when `--tag=profile-hybrid-2020-09-01` is specified on the command line.

``` yaml $(tag) == 'profile-hybrid-2020-09-01'
input-file:
- Microsoft.Network/stable/2016-04-01/dns.json
```

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
    after_scripts:
      - python ./scripts/multiapi_init_gen.py azure-mgmt-dns
  - repo: azure-sdk-for-python-track2
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-typescript
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_dns']
  - repo: azure-resource-manager-schemas
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Python

See configuration in [readme.python.md](./readme.python.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.dns
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-dns
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2017-10
  - tag: package-2016-04
```

### Tag: package-2017-10 and java

These settings apply only when `--tag=package-2017-10 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2017-10' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.dns.v2017_10_01
  output-folder: $(azure-libraries-for-java-folder)/sdk/dns/mgmt-v2017_10_01
regenerate-manager: true
generate-interface: true
```

### Tag: package-2016-04 and java

These settings apply only when `--tag=package-2016-04 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2016-04' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.dns.v2016_04_01
  output-folder: $(azure-libraries-for-java-folder)/sdk/dns/mgmt-v2016_04_01
regenerate-manager: true
generate-interface: true
```

### Tag: profile-hybrid-2019-03-01

These settings apply only when `--tag=profile-hybrid-2019-03-01` is specified on the command line.
Creating this tag to pick proper resources from the hybrid profile.

``` yaml $(tag) == 'profile-hybrid-2019-03-01'
input-file:
- Microsoft.Network/stable/2016-04-01/dns.json
```



