# Scheduler

> see https://aka.ms/autorest

This is the AutoRest configuration file for Scheduler.



---
## Getting Started
To build the SDK for Scheduler, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the Scheduler API.

``` yaml
openapi-type: arm
tag: package-2016-03
```


### Tag: package-2016-03

These settings apply only when `--tag=package-2016-03` is specified on the command line.

``` yaml $(tag) == 'package-2016-03'
input-file:
- Microsoft.Scheduler/stable/2016-03-01/scheduler.json
```

### Tag: package-2016-01

These settings apply only when `--tag=package-2016-01` is specified on the command line.

``` yaml $(tag) == 'package-2016-01'
input-file:
- Microsoft.Scheduler/stable/2016-01-01/scheduler.json
```

### Tag: package-2014-08-preview

These settings apply only when `--tag=package-2014-08-preview` is specified on the command line.

``` yaml $(tag) == 'package-2014-08-preview'
input-file:
- Microsoft.Scheduler/preview/2014-08-01-preview/scheduler.json
```


---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-net
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_scheduler']
  - repo: azure-resource-manager-schemas
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: NONE
  namespace: Microsoft.Azure.Management.Scheduler
  output-folder: $(csharp-sdks-folder)/scheduler/Microsoft.Azure.Management.Scheduler/src/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python) && !$(track2)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.scheduler
  package-name: azure-mgmt-scheduler
  clear-output-folder: true
```

``` yaml $(python) && $(track2)
python-mode: create
azure-arm: true
license-header: MICROSOFT_MIT_NO_VERSION
namespace: azure.mgmt.scheduler
package-name: azure-mgmt-scheduler
package-version: 7.0.0b1
clear-output-folder: true
```

``` yaml $(python) && $(python-mode) == 'update'
no-namespace-folders: true
output-folder: $(python-sdks-folder)/scheduler/azure-mgmt-scheduler/azure/mgmt/scheduler
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/scheduler/azure-mgmt-scheduler/azure/mgmt/scheduler
```
``` yaml $(python) && $(python-mode) == 'create'
basic-setup-py: true
output-folder: $(python-sdks-folder)/scheduler/azure-mgmt-scheduler
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/scheduler/azure-mgmt-scheduler
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.scheduler
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-scheduler
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2014-08-preview
  - tag: package-2016-01
  - tag: package-2016-03
```

### Tag: package-2014-08-preview and java

These settings apply only when `--tag=package-2014-08-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2014-08-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.scheduler.v2014_08_01_preview
  output-folder: $(azure-libraries-for-java-folder)/sdk/scheduler/mgmt-v2014_08_01_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2016-01 and java

These settings apply only when `--tag=package-2016-01 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2016-01' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.scheduler.v2016_01_01
  output-folder: $(azure-libraries-for-java-folder)/sdk/scheduler/mgmt-v2016_01_01
regenerate-manager: true
generate-interface: true
```

### Tag: package-2016-03 and java

These settings apply only when `--tag=package-2016-03 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2016-03' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.scheduler.v2016_03_01
  output-folder: $(azure-libraries-for-java-folder)/sdk/scheduler/mgmt-v2016_03_01
regenerate-manager: true
generate-interface: true
```





